@@ -2,8 +2,9 @@
 Name               : callbacks.c
 Author             : Marvin Raaijmakers
 Description        : Handles callbacks of the user interface
-Date of last change: 30-Aug-2006
-History            : 30-Aug-2006 Added support for ACPI hotkeys (not finished)
+Date of last change: 24-Jun-2007
+History            : 24-Jun-2007 Compiler warnings fixes
+                     30-Aug-2006 Added support for ACPI hotkeys (not finished)
                      01-Jul-2006 Added syntax check call to save_keyboard_file()
                      29-Apr-2006 save_keyboard_file() asks for a confirmation
                                  before overwriting a file
@@ -11,7 +12,7 @@ History            : 30-Aug-2006 Added support for ACPI hotkeys (not finished)
                                  the new key to the user, if the key is known and
                                  fills in the default action for such key.
 
-    Copyright (C) 2006 Marvin Raaijmakers
+    Copyright (C) 2006-2007 Marvin Raaijmakers
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -34,10 +35,12 @@ History            : 30-Aug-2006 Added support for ACPI hotkeys (not finished)
 #  include <config.h>
 #endif
 
-#include <gtk/gtk.h>
+#define _GNU_SOURCE
 #include <stdlib.h>
 #include <stdio.h>
+#include <string.h>
 #include <unistd.h>
+#include <gtk/gtk.h>
 
 #include "callbacks.h"
 #include "interface.h"
@@ -246,9 +249,9 @@ Description:
 				*author,
 				*email_address,
 				*subject;
-	GtkDialog		*overwrite_question_dialog;
-	GtkMessageDialog	*msg_dialog;
-	GtkWidget		*send_question_dialog,
+	GtkWidget		*overwrite_question_dialog,
+				*msg_dialog,
+				*send_question_dialog,
 				*contact_dialog,
 				*save_dialog;
 	Boolean			send_keyboard_file,
@@ -258,7 +261,6 @@ Description:
 						 * of this function it indicates if the file
 						 * was successfully saved.
 						 */
-	int			file_access;
 	
 	manufacturer = (char *) gtk_entry_get_text( GTK_ENTRY(
 	                           lookup_widget(this_widget, "manufacturer_entry") ) );
@@ -922,9 +924,7 @@ on_key_treeview_selection (	GtkTreeSelection	*selection,
 	GtkRadioButton		*selected_radiobutton,
 				*program_radiobutton,
 				*plugin_radiobutton;
-	GtkComboBox		*keycode_combobox,
-				*plugin_combobox,
-				*plugin_function_combobox;
+	GtkComboBox		*keycode_combobox;
 	GtkTreeView		*key_treeview;
 	GtkLabel		*scancode_event_descr_label;
 	static GtkTreeIter	iter;
@@ -1070,6 +1070,7 @@ on_main_window_delete_event            (GtkWidget       *widget,
 	KTKeyList_clear (&key_list);
 	gtk_main_quit();
 	gtk_exit (0);
+	return FALSE;
 }
 
 
