@@ -2,8 +2,9 @@
 Name               : check_syntax.c
 Author             : Marvin Raaijmakers
 Description        : Checks if the syntax of a keyboard file is valid
-Date of last change: 17-Sep-2006
-History            : 17-Sep-2006 Added support for ACPI hotkeys
+Date of last change: 24-Jun-2007
+History            : 24-Jun-2007 Compiler warnings fixes
+                     17-Sep-2006 Added support for ACPI hotkeys
                      24-Jun-2006 Added checks for keycodes and scancodes
 
     Copyright (C) 2006 Marvin Raaijmakers
@@ -25,8 +26,10 @@ History            : 17-Sep-2006 Added support for ACPI hotkeys
     You can contact me at: marvinr(at)users(dot)sf(dot)net
     (replace (at) by @ and (dot) by .)
 -----------------------------------------------------------------------------------*/
+#define _XOPEN_SOURCE /* glibc2 needs this */
 #include <stdlib.h>
 #include <stdio.h>
+#include <string.h>
 #include <time.h>
 
 #include <mxml.h>
