@@ -2,11 +2,12 @@
 Name               : config.c
 Author             : Marvin Raaijmakers
 Description        : Reads and writes the keyboard files
-Date of last change: ??-Sep-2006
-History            : ??-Sep-2006 Added support for ACPI hotkeys
+Date of last change: 24-Jun-2007
+History            : 24-Jun-2007 Compiler warnings fixes
+                     ??-Sep-2006 Added support for ACPI hotkeys
                      01-Jul-2006 Added keyboard_file_is_valid()
 
-    Copyright (C) 2005-2006 Marvin Raaijmakers
+    Copyright (C) 2005-2007 Marvin Raaijmakers
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -188,7 +189,6 @@ Desciption:
 			*default_action_element;
 	char		*tmp_string, *key_type_string;
 	KTKey		*key;
-	unsigned int	scancode, keycode;
 	
 	key_element = XmlGetElementOfType(XmlElementContentList(keylist_element), key_type, index);
 	if (key_element == NULL)
@@ -418,6 +418,7 @@ Desciption:
 		}
 	}
 	XmlFreeDocument (document);
+	return TRUE;
 }
 
 
